<?php
/**
 * Portuguese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author José Carlos Monteiro <jose.c.monteiro@netcabo.pt>
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 */
$lang['admin_acl']             = 'Gestão de ACLs';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Utilizador';
$lang['acl_perms']             = 'Permissão para';
$lang['page']                  = 'Documento';
$lang['namespace']             = 'Namespace';
$lang['btn_select']            = 'Selecionar';
$lang['current']               = 'Regras Actuais ACL';
$lang['where']                 = 'Página/Espaço de Nomes';
$lang['who']                   = 'Utilizador/Grupo';
$lang['perm']                  = 'Permissões';
$lang['acl_perm0']             = 'Nenhum';
$lang['acl_perm1']             = 'Ler';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Criar';
$lang['acl_perm8']             = 'Carregar';
$lang['acl_perm16']            = 'Remover';
$lang['acl_new']               = 'Adicionar nova entrada';
$lang['acl_mod']               = 'Modificar Entrada';
